# Cadence Flow

**This is a placeholder package for the `cadence-flow` project.**

The project is under active development. The goal of `cadence-flow` is to provide an open-source Python library for building, managing, and supervising human-in-the-loop (HITL) AI workflows.

### Stay Updated

You can follow our development and find the source code at our official GitHub organization:

**https://github.com/cadence-flow**

Thank you for your interest!